|logo|

Gala is a Python package for Galactic and gravitational dynamics.

|Affiliated package| |Coverage Status| |Build status|

Documentation
-------------

|Documentation Status|

The documentation for ``Gala`` is hosted on `Read the docs
<http://gala.adrian.pw>`__.

Installation and Dependencies
-----------------------------

|conda| |PyPI|

The easiest way to get Gala is to install with pip or conda.

The recommended install method is to use ``pip``::

   pip install gala

If you are on Linux or Mac, you can also install ``gala`` with conda using the
conda-forge channel::

    conda install gala --channel conda-forge

See the `installation
instructions <http://gala.adrian.pw/en/latest/install.html>`_ in the
`documentation <http://gala.adrian.pw>`__ for more information.

Attribution
-----------

|JOSS| |DOI|

If you make use of this code, please cite the `JOSS <http://joss.theoj.org>`_
paper::

    @article{gala,
      doi = {10.21105/joss.00388},
      url = {https://doi.org/10.21105%2Fjoss.00388},
      year = 2017,
      month = {oct},
      publisher = {The Open Journal},
      volume = {2},
      number = {18},
      author = {Adrian M. Price-Whelan},
      title = {Gala: A Python package for galactic dynamics},
      journal = {The Journal of Open Source Software}
    }

Please also cite the Zenodo DOI |DOI| as a software citation - see the
`documentation
<http://gala.adrian.pw/en/latest/index.html#citation-and-attribution>`_ for up
to date citation information.

License
-------

|License|

Copyright 2013-2024 Adrian Price-Whelan and contributors.

``Gala`` is free software made available under the MIT License. For details see
the `LICENSE <https://github.com/adrn/gala/blob/main/LICENSE>`_ file.

.. |Coverage Status| image:: https://codecov.io/gh/adrn/gala/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/adrn/gala
.. |Build status| image:: https://github.com/adrn/gala/actions/workflows/tests.yml/badge.svg
   :target: https://github.com/adrn/gala/actions/workflows/tests.yml
.. |License| image:: http://img.shields.io/badge/license-MIT-blue.svg?style=flat
   :target: https://github.com/adrn/gala/blob/main/LICENSE
.. |PyPI| image:: https://badge.fury.io/py/gala.svg
   :target: https://badge.fury.io/py/gala
.. |conda| image:: https://anaconda.org/conda-forge/gala/badges/version.svg
   :target: https://anaconda.org/conda-forge/gala
.. |Documentation Status| image:: https://readthedocs.org/projects/gala-astro/badge/?version=latest
   :target: http://gala-astro.readthedocs.io/en/latest/?badge=latest
.. |Affiliated package| image:: https://img.shields.io/badge/astropy-affiliated%20package-orange.svg
   :target: http://astropy.org/affiliated
.. |JOSS| image:: http://joss.theoj.org/papers/10.21105/joss.00388/status.svg
   :target: http://joss.theoj.org/papers/10.21105/joss.00388
.. |DOI| image:: https://zenodo.org/badge/17577779.svg
   :target: https://zenodo.org/badge/latestdoi/17577779
.. |ASCL| image:: https://img.shields.io/badge/ascl-1707.006-blue.svg?colorB=262255
   :target: http://ascl.net/1707.006
.. |logo| image:: https://gala.adrian.pw/en/latest/_static/Gala_Logo_RGB.png
   :target: https://github.com/adrn/gala
   :width: 400

Contributors
------------

See the `AUTHORS.rst <https://github.com/adrn/gala/blob/main/AUTHORS.rst>`_
file for a complete list of contributors to the project.
